summaryrefslogtreecommitdiffstats
path: root/libtdepim/distributionlist.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libtdepim/distributionlist.cpp')
-rw-r--r--libtdepim/distributionlist.cpp42
1 files changed, 21 insertions, 21 deletions
diff --git a/libtdepim/distributionlist.cpp b/libtdepim/distributionlist.cpp
index f5742a14..2fd50f5a 100644
--- a/libtdepim/distributionlist.cpp
+++ b/libtdepim/distributionlist.cpp
@@ -4,13 +4,13 @@
static const char* s_customFieldName = "DistributionList";
KPIM::DistributionList::DistributionList()
- : KABC::Addressee()
+ : TDEABC::Addressee()
{
// can't insert the custom entry here, we need to remain a null addressee
}
-KPIM::DistributionList::DistributionList( const KABC::Addressee& addr )
- : KABC::Addressee( addr )
+KPIM::DistributionList::DistributionList( const TDEABC::Addressee& addr )
+ : TDEABC::Addressee( addr )
{
}
@@ -91,19 +91,19 @@ void KPIM::DistributionList::removeEntry( const TQString& uid, const TQString& e
insertCustom( "KADDRESSBOOK", s_customFieldName, str ); // replace old value
}
-bool KPIM::DistributionList::isDistributionList( const KABC::Addressee& addr )
+bool KPIM::DistributionList::isDistributionList( const TDEABC::Addressee& addr )
{
const TQString str = addr.custom( "KADDRESSBOOK", s_customFieldName );
return !str.isEmpty();
}
-// ###### KDE4: add findByFormattedName to KABC::AddressBook
-static KABC::Addressee::List findByFormattedName( KABC::AddressBook* book,
+// ###### KDE4: add findByFormattedName to TDEABC::AddressBook
+static TDEABC::Addressee::List findByFormattedName( TDEABC::AddressBook* book,
const TQString& name,
bool caseSensitive = true )
{
- KABC::Addressee::List res;
- KABC::AddressBook::Iterator abIt;
+ TDEABC::Addressee::List res;
+ TDEABC::AddressBook::Iterator abIt;
for ( abIt = book->begin(); abIt != book->end(); ++abIt )
{
if ( caseSensitive && (*abIt).formattedName() == name )
@@ -114,11 +114,11 @@ static KABC::Addressee::List findByFormattedName( KABC::AddressBook* book,
return res;
}
-KPIM::DistributionList KPIM::DistributionList::findByName( KABC::AddressBook* book,
+KPIM::DistributionList KPIM::DistributionList::findByName( TDEABC::AddressBook* book,
const TQString& name,
bool caseSensitive )
{
- KABC::AddressBook::Iterator abIt;
+ TDEABC::AddressBook::Iterator abIt;
for ( abIt = book->begin(); abIt != book->end(); ++abIt )
{
if ( isDistributionList( *abIt ) ) {
@@ -131,16 +131,16 @@ KPIM::DistributionList KPIM::DistributionList::findByName( KABC::AddressBook* bo
return DistributionList();
}
-static KABC::Addressee findByUidOrName( KABC::AddressBook* book, const TQString& uidOrName, const TQString& email )
+static TDEABC::Addressee findByUidOrName( TDEABC::AddressBook* book, const TQString& uidOrName, const TQString& email )
{
- KABC::Addressee a = book->findByUid( uidOrName );
+ TDEABC::Addressee a = book->findByUid( uidOrName );
if ( a.isEmpty() ) {
// UID not found, maybe it is a name instead.
// If we have an email, let's use that for the lookup.
// [This is used by e.g. the Kolab resource]
if ( !email.isEmpty() ) {
- KABC::Addressee::List lst = book->findByEmail( email );
- KABC::Addressee::List::ConstIterator listit = lst.begin();
+ TDEABC::Addressee::List lst = book->findByEmail( email );
+ TDEABC::Addressee::List::ConstIterator listit = lst.begin();
for ( ; listit != lst.end(); ++listit )
if ( (*listit).formattedName() == uidOrName ) {
a = *listit;
@@ -153,7 +153,7 @@ static KABC::Addressee findByUidOrName( KABC::AddressBook* book, const TQString&
// If we don't have an email, or if we didn't find any match for it, look up by full name
if ( a.isEmpty() ) {
// (But this has to be done here, since when loading we might not have the entries yet)
- KABC::Addressee::List lst = findByFormattedName( book, uidOrName );
+ TDEABC::Addressee::List lst = findByFormattedName( book, uidOrName );
if ( !lst.isEmpty() )
a = lst.first();
}
@@ -161,7 +161,7 @@ static KABC::Addressee findByUidOrName( KABC::AddressBook* book, const TQString&
return a;
}
-KPIM::DistributionList::Entry::List KPIM::DistributionList::entries( KABC::AddressBook* book ) const
+KPIM::DistributionList::Entry::List KPIM::DistributionList::entries( TDEABC::AddressBook* book ) const
{
Entry::List res;
const TQString str = custom( "KADDRESSBOOK", s_customFieldName );
@@ -170,7 +170,7 @@ KPIM::DistributionList::Entry::List KPIM::DistributionList::entries( KABC::Addre
const TQString uid = (*it).first;
const TQString email = (*it).second;
// look up contact
- KABC::Addressee a = findByUidOrName( book, uid, email );
+ TDEABC::Addressee a = findByUidOrName( book, uid, email );
if ( a.isEmpty() ) {
// ## The old DistributionListManager had a "missing entries" list...
kdWarning() << "Addressee not found: " << uid << endl;
@@ -181,7 +181,7 @@ KPIM::DistributionList::Entry::List KPIM::DistributionList::entries( KABC::Addre
return res;
}
-TQStringList KPIM::DistributionList::emails( KABC::AddressBook* book ) const
+TQStringList KPIM::DistributionList::emails( TDEABC::AddressBook* book ) const
{
TQStringList emails;
@@ -192,7 +192,7 @@ TQStringList KPIM::DistributionList::emails( KABC::AddressBook* book ) const
const TQString thisEmail = (*it).second;
// look up contact
- KABC::Addressee a = findByUidOrName( book, thisUid, thisEmail );
+ TDEABC::Addressee a = findByUidOrName( book, thisUid, thisEmail );
if ( a.isEmpty() ) {
// ## The old DistributionListManager had a "missing entries" list...
continue;
@@ -209,10 +209,10 @@ TQStringList KPIM::DistributionList::emails( KABC::AddressBook* book ) const
}
TQValueList<KPIM::DistributionList>
- KPIM::DistributionList::allDistributionLists( KABC::AddressBook* book )
+ KPIM::DistributionList::allDistributionLists( TDEABC::AddressBook* book )
{
TQValueList<KPIM::DistributionList> lst;
- KABC::AddressBook::Iterator abIt;
+ TDEABC::AddressBook::Iterator abIt;
for ( abIt = book->begin(); abIt != book->end(); ++abIt )
{
if ( isDistributionList( *abIt ) ) {